@@ -10,17 +10,18 @@ from typing import Optional
 import rich
 import click
 
+from sqeleton.schema import create_schema
+from sqeleton.queries.api import current_timestamp
+
 from .utils import eval_name_template, remove_password_from_url, safezip, match_like
 from .diff_tables import Algorithm
 from .hashdiff_tables import HashDiffer, DEFAULT_BISECTION_THRESHOLD, DEFAULT_BISECTION_FACTOR
 from .joindiff_tables import TABLE_WRITE_LIMIT, JoinDiffer
 from .table_segment import TableSegment
-from .sqeleton.schema import create_schema
-from .sqeleton.queries.api import current_timestamp
 from .databases import connect
 from .parse_time import parse_time_before, UNITS_STR, ParseError
 from .config import apply_config_from_file
-from .tracking import disable_tracking
+from .tracking import disable_tracking, set_entrypoint_name
 from .version import __version__
 
 
@@ -32,6 +33,8 @@ COLOR_SCHEME = {
     "-": "red",
 }
 
+set_entrypoint_name("CLI")
+
 
 def _remove_passwords_in_dict(d: dict):
     for k, v in d.items():
@@ -182,7 +185,7 @@ click.Context.formatter_class = MyHelpFormatter
     metavar="COUNT",
 )
 @click.option(
-    "-w", "--where", default=None, help="An additional 'where' expression to restrict the search space.", metavar="EXPR"
+    "-w", "--where", default=None, help="An additional 'where' expression to restrict the search space. Beware of SQL Injection!", metavar="EXPR"
 )
 @click.option("-a", "--algorithm", default=Algorithm.AUTO.value, type=click.Choice([i.value for i in Algorithm]))
 @click.option(
@@ -307,18 +310,22 @@ def _main(
     else:
         db2 = connect(database2, threads2 or threads)
 
-    now: datetime = db1.query(current_timestamp(), datetime)
-    now = now.replace(tzinfo=None)
-    try:
-        options = dict(
-            min_update=max_age and parse_time_before(now, max_age),
-            max_update=min_age and parse_time_before(now, min_age),
-            case_sensitive=case_sensitive,
-            where=where,
-        )
-    except ParseError as e:
-        logging.error(f"Error while parsing age expression: {e}")
-        return
+    options = dict(
+        case_sensitive=case_sensitive,
+        where=where,
+    )
+
+    if min_age or max_age:
+        now: datetime = db1.query(current_timestamp(), datetime)
+        now = now.replace(tzinfo=None)
+        try:
+            if max_age:
+                options["min_update"] = parse_time_before(now, max_age)
+            if min_age:
+                options["max_update"] = parse_time_before(now, min_age)
+        except ParseError as e:
+            logging.error(f"Error while parsing age expression: {e}")
+            return
 
     dbs = db1, db2
 
