@@ -26,17 +26,22 @@ def _apply_config(config: Dict[str, Any], run_name: str, kw: Dict[str, Any]):
     else:
         run_name = "default"
 
-    if 'database1' in kw:
-        for attr in ('table1', 'database2', 'table2'):
+    if kw.get("database1") is not None:
+        for attr in ("table1", "database2", "table2"):
             if kw[attr] is None:
-                raise ValueError(f"Specified database1 but not {attr}. Must specify all 4 arguments, or niether.")
+                raise ValueError(f"Specified database1 but not {attr}. Must specify all 4 arguments, or neither.")
 
         for index in "12":
-            run_args[index] = {attr: kw.pop(f"{attr}{index}") for attr in ('database', 'table')}
+            run_args[index] = {attr: kw.pop(f"{attr}{index}") for attr in ("database", "table")}
 
     # Process databases + tables
     for index in "12":
-        args = run_args.pop(index, {})
+        try:
+            args = run_args.pop(index)
+        except KeyError:
+            raise ConfigParseError(
+                f"Could not find source #{index}: Expecting a key of '{index}' containing '.database' and '.table'."
+            )
         for attr in ("database", "table"):
             if attr not in args:
                 raise ConfigParseError(f"Running 'run.{run_name}': Connection #{index} is missing attribute '{attr}'.")
